useDynLib(gMCP, .registration = TRUE)

import(methods)
importFrom("graphics", "par", "plot.new", "strwidth", "axis", "box", "abline", "arrows", "persp") 
importFrom("stats", "setNames", "pnorm", "cov2cor", "uniroot", "coef", "qnorm", "runif", "rnorm", "qt")
# See https://stat.ethz.ch/pipermail/r-devel/2012-February/063396.html :
importFrom(stats4, plot)
import(utils)
import(rJava)
# Superfluous since xlsxjars has no functions (but still here for CRAN checks):
import(xlsxjars)
importFrom(CommonJavaJars, loadJars)
importFrom(PolynomF, polynom)
importFrom(mvtnorm, pmvnorm)
importFrom(MASS, fractions)
importFrom(multcomp, contrMat)
# These methods are directly called by the GUI - we note them here for the CRAN checks:
importFrom(JavaGD, JavaGD)
importFrom(Matrix, bdiag)

exportClasses(graphMCP, gMCPResult, gPADInterim, entangledMCP)
exportMethods(plot, print)
exportMethods(getWeights, getMatrix, getMatrices, setWeights, getRejected, "setRejected<-", getXCoordinates, getYCoordinates)
exportMethods(simConfint, setEdge, edgeAttr, "edgeAttr<-", nodeAttr, "nodeAttr<-", getNodes)

export(graphGUI, corMatWizard)
export(gMCP, rejectNode, substituteEps, placeNodes, gMCP.extended)
export(bonferroni.test, parametric.test, bonferroni.trimmed.simes.test, simes.on.subsets.test, simes.test)
export(gMCPReport, graph2latex)
export(matrix2graph, graph2matrix, bdiagNA, joinGraphs, subgraph)
export(graphAnalysis)
export(replaceVariables)
export(unitTestsGMCP)
export(getJavaInfo)

export(BonferroniHolm)
export(BretzEtAl2011)
export(truncatedHolm)
export(fixedSequence)
export(generalSuccessive, simpleSuccessiveI, simpleSuccessiveII)
export(HommelEtAl2007, HommelEtAl2007Simple)
export(HungEtWang2010)
export(MaurerEtAl1995)
export(BauerEtAl2001)
export(BretzEtAl2009a, BretzEtAl2009b, BretzEtAl2009c)
export(parallelGatekeeping, improvedParallelGatekeeping)
export(fallback, improvedFallbackI, improvedFallbackII)
export(cycleGraph)
export(HuqueAloshEtBhore2011)
export(Ferber2011, FerberTimeDose2011)
export(Entangled1Maurer2012, Entangled2Maurer2012)
export(WangTing2014)

export(extractPower, calcPower, graphTest, rqmvnorm)
export(plotSimCI)

export(generateWeights, generateBounds, generateTest, generatePvals)

export(sampSize)

export(doInterim,secondStageTest)
